.. _algorithms:

**********
Algorithms
**********

.. currentmodule:: networkx


.. toctree::
   :maxdepth: 2

   algorithms.boundary
   algorithms.centrality
   algorithms.clique
   algorithms.clustering
   algorithms.core
   algorithms.matching
   algorithms.isomorphism
   algorithms.pagerank
   algorithms.hits
   algorithms.traversal
   algorithms.bipartite
   algorithms.mst

